@@ -616,7 +616,7 @@ class AgentsGenerator:
             llm_model = details.get('llm')
             if llm_model:
                 llm = PraisonAIModel(
-                    model=llm_model.get("model") or os.environ.get("MODEL_NAME") or "openai/gpt-4o-mini",
+                    model=llm_model.get("model") or os.environ.get("MODEL_NAME") or "openai/gpt-5-nano",
                     base_url=self.config_list[0].get('base_url') if self.config_list else None,
                     api_key=self.config_list[0].get('api_key') if self.config_list else None
                 ).get_model()
@@ -630,7 +630,7 @@ class AgentsGenerator:
             function_calling_llm_model = details.get('function_calling_llm')
             if function_calling_llm_model:
                 function_calling_llm = PraisonAIModel(
-                    model=function_calling_llm_model.get("model") or os.environ.get("MODEL_NAME") or "openai/gpt-4o-mini",
+                    model=function_calling_llm_model.get("model") or os.environ.get("MODEL_NAME") or "openai/gpt-5-nano",
                     base_url=self.config_list[0].get('base_url') if self.config_list else None,
                     api_key=self.config_list[0].get('api_key') if self.config_list else None
                 ).get_model()
@@ -746,8 +746,8 @@ class AgentsGenerator:
                 backstory=backstory_filled,
                 tools=tools_list,  # Pass the entire tools list to the agent
                 allow_delegation=details.get('allow_delegation', False),
-                llm=details.get('llm', {}).get("model") or os.environ.get("MODEL_NAME") or "openai/gpt-4o-mini",
-                function_calling_llm=details.get('function_calling_llm', {}).get("model") or os.environ.get("MODEL_NAME") or "openai/gpt-4o-mini",
+                llm=details.get('llm', {}).get("model") or os.environ.get("MODEL_NAME") or "openai/gpt-5-nano",
+                function_calling_llm=details.get('function_calling_llm', {}).get("model") or os.environ.get("MODEL_NAME") or "openai/gpt-5-nano",
                 max_iter=details.get('max_iter', 15),
                 max_rpm=details.get('max_rpm'),
                 max_execution_time=details.get('max_execution_time'),
@@ -756,7 +756,7 @@ class AgentsGenerator:
                 system_template=details.get('system_template'),
                 prompt_template=details.get('prompt_template'),
                 response_template=details.get('response_template'),
-                reflect_llm=details.get('reflect_llm', {}).get("model") or os.environ.get("MODEL_NAME") or "openai/gpt-4o-mini",
+                reflect_llm=details.get('reflect_llm', {}).get("model") or os.environ.get("MODEL_NAME") or "openai/gpt-5-nano",
                 min_reflect=details.get('min_reflect', 1),
                 max_reflect=details.get('max_reflect', 3),
             )
@@ -812,7 +812,7 @@ class AgentsGenerator:
                 tasks=tasks,
                 verbose=True,
                 process="hierarchical",
-                manager_llm=config.get('manager_llm') or os.environ.get("MODEL_NAME") or "openai/gpt-4o-mini",
+                manager_llm=config.get('manager_llm') or os.environ.get("MODEL_NAME") or "openai/gpt-5-nano",
                 memory=memory
             )
         else:
