@@ -225,7 +225,7 @@ async def send_count():
 
 @cl.on_chat_start
 async def start():
-    model_name = load_setting("model_name") or os.getenv("MODEL_NAME", "gpt-4o-mini")
+    model_name = load_setting("model_name") or os.getenv("MODEL_NAME", "gpt-5-nano")
     cl.user_session.set("model_name", model_name)
     logger.debug(f"Model name: {model_name}")
     settings = cl.ChatSettings(
@@ -233,7 +233,7 @@ async def start():
             TextInput(
                 id="model_name",
                 label="Enter the Model Name",
-                placeholder="e.g., gpt-4o-mini",
+                placeholder="e.g., gpt-5-nano",
                 initial=model_name
             )
         ]
@@ -266,7 +266,7 @@ async def setup_agent(settings):
 
 @cl.on_message
 async def main(message: cl.Message):
-    model_name = load_setting("model_name") or os.getenv("MODEL_NAME", "gpt-4o-mini")
+    model_name = load_setting("model_name") or os.getenv("MODEL_NAME", "gpt-5-nano")
     message_history = cl.user_session.get("message_history", [])
     now = datetime.now().strftime("%Y-%m-%d %H:%M:%S")
 
@@ -452,14 +452,14 @@ User Question: {message.content}
 @cl.on_chat_resume
 async def on_chat_resume(thread: ThreadDict):
     logger.info(f"Resuming chat: {thread['id']}")
-    model_name = load_setting("model_name") or os.getenv("MODEL_NAME", "gpt-4o-mini")
+    model_name = load_setting("model_name") or os.getenv("MODEL_NAME", "gpt-5-nano")
     logger.debug(f"Model name: {model_name}")
     settings = cl.ChatSettings(
         [
             TextInput(
                 id="model_name",
                 label="Enter the Model Name",
-                placeholder="e.g., gpt-4o-mini",
+                placeholder="e.g., gpt-5-nano",
                 initial=model_name
             )
         ]
